package dev.fyloz.colorrecipesexplorer

object Constants {
    val BEARER_PREFIX = "Bearer"
    var DEBUG_MODE = false  // Not really a constant, but should never change after the app startup

    object ControllerPaths {
        const val BASE_PATH = "/api"
        const val ACCOUNT_BASE_PATH = "$BASE_PATH/account"

        const val COMPANY = "$BASE_PATH/company"
        const val GROUP_TOKEN = "$BASE_PATH/account/group/token"
        const val FILE = "$BASE_PATH/file"
        const val INVENTORY = "$BASE_PATH/inventory"
        const val MATERIAL = "$BASE_PATH/material"
        const val MATERIAL_TYPE = "$BASE_PATH/materialtype"
        const val MIX = "$BASE_PATH/recipe/mix"
        const val RECIPE = "$BASE_PATH/recipe"
        const val TOUCH_UP_KIT = "$BASE_PATH/touchupkit"

        const val GROUP = "$ACCOUNT_BASE_PATH/group"
        const val GROUP_LOGIN = "$ACCOUNT_BASE_PATH/login/group"
        const val LOGIN = "$ACCOUNT_BASE_PATH/login"
        const val LOGOUT = "$ACCOUNT_BASE_PATH/logout"
        const val USER = "$ACCOUNT_BASE_PATH/user"
    }

    object CookieNames {
        const val AUTHORIZATION = "Authorization"
        const val GROUP_TOKEN = "Group-Token"
    }

    object FilePaths {
        private const val PDF = "pdf"
        private const val IMAGES = "images"

        const val SIMDUT = "$PDF/simdut"
        const val TOUCH_UP_KITS = "$PDF/touchupkits"
        const val RECIPE_IMAGES = "$IMAGES/recipes"
    }

    object JwtType {
        const val USER = 0
        const val GROUP = 1
    }

    object ModelNames {
        const val COMPANY = "Company"
        const val GROUP_TOKEN = "GroupToken"
        const val GROUP = "Group"
        const val MATERIAL = "Material"
        const val MATERIAL_TYPE = "MaterialType"
        const val MIX = "Mix"
        const val MIX_MATERIAL = "MixMaterial"
        const val MIX_TYPE = "MixType"
        const val RECIPE = "Recipe"
        const val RECIPE_STEP = "RecipeStep"
        const val TOUCH_UP_KIT = "TouchUpKit"
        const val USER = "User"
    }

    object ValidationMessages {
        const val SIZE_GREATER_OR_EQUALS_ZERO = "Must be greater or equals to 0"
        const val SIZE_GREATER_OR_EQUALS_ONE = "Must be greater or equals to 1"
        const val RANGE_OUTSIDE_PERCENTS = "Must be between 0 and 100"
        const val PASSWORD_TOO_SMALL = "Must contains at least 8 characters"
    }

    object ValidationRegexes {
        const val VALIDATION_COLOR_PATTERN = "^#([0-9a-f]{6})$"
    }
}
